from __future__ import annotations

from typing import Dict, List, Any, Tuple
from pathlib import Path
import json

from .service import ServiceStatus, ServiceStatusGroup, BaseProtocol, support_protocol
from .exception import (
    ProtocolUnsopportError,
    NameConflictError,
    NameNotFoundError,
    ParamInvalidError,
)


class CommandManager:
    __service_status: ServiceStatus = ServiceStatus()
    __service_status_group: ServiceStatusGroup = ServiceStatusGroup()

    def __init__(self) -> None:
        pass

    def load(self, path: Path):
        with open(path, "r", encoding="utf-8") as f:
            load_dict = json.loads(f.read())
        self.__service_status = ServiceStatus.load(load_dict["service"])
        self.__service_status_group = ServiceStatusGroup.load(
            load_dict["service_group"]
        )

    def save(self, path: Path):
        save_dict = {
            "service": self.__service_status.export(),
            "service_group": self.__service_status_group.export(),
        }
        with open(path, "w", encoding="utf-8") as f:
            f.write(json.dumps(save_dict))

    def bind_new_service(self, protocol: str, name: str, host: str):
        if protocol not in support_protocol():
            raise ProtocolUnsopportError
        if name in self.__service_status:
            raise NameConflictError
        if name in self.__service_status_group:
            raise NameConflictError
        self.__service_status.bind_service(
            BaseProtocol._support_protocol[protocol](name=name, host=host)
        )

    def unbind_service_by_name(self, name: str):
        if name in self.__service_status:
            self.__service_status.unbind_service_by_name(name)
            return
        if name in self.__service_status_group:
            self.__service_status_group.unbind_group_by_name(name)
            return
        raise NameNotFoundError

    def bind_group_by_name(self, service_name_list: List[str], name: str):
        service_instance_list: List[BaseProtocol] = []
        for i in service_name_list:
            service_instance_list.append(
                self.__service_status.get_service_instance_by_name(i)
            )
        self.__service_status_group.bind_group(service_instance_list, name)
        for i in service_instance_list:
            self.__service_status.unbind_service(i)

    def modify_service_param(self, name: str, key: str, value: str):
        for i, j in enumerate(self.__service_status.bind_services):
            if j == name:
                temp_config = j.export()
                if key not in temp_config:
                    raise ParamInvalidError
                temp_config[key] = value
                self.__service_status.bind_services[i] = j.load(temp_config)
                return
        raise NameNotFoundError

    async def get_detect_result(self):
        return dict(
            (await self.__service_status.get_detect_result()),
            **(await self.__service_status_group.get_detect_result()),
        )



from typing import Dict, List, Any, Tuple
from pathlib import Path
from pydantic import ValidationError

from nonebot.plugin.on import on_command
from nonebot.params import CommandArg, Depends
from nonebot.adapters.onebot.v11 import Message
from nonebot.log import logger
from nonebot.permission import SUPERUSER

from .service import support_protocol
from .exception import (
    ProtocolUnsopportError,
    NameConflictError,
    NameNotFoundError,
    ParamCountInvalidError,
)
from .manager import CommandManager

CONFIG_FILE_PATH = Path(__file__).parent.joinpath("config.txt")
manager = CommandManager()
manager.load(CONFIG_FILE_PATH)

service_status_matcher = on_command("服务状态")


@service_status_matcher.handle()
async def _():
    result_dict = await manager.get_detect_result()
    if result_dict == {}:
        await service_status_matcher.finish("您未绑定任何监控的服务！")
    pretty_text = ""
    for name, result in result_dict.items():
        pretty_text += "O" if result else "X"
        # pretty_text += "" if result else " "  # QQ字符O和X宽度不一致
        pretty_text += " "
        pretty_text += "正常" if result else "故障"
        pretty_text += " | "
        pretty_text += name
        pretty_text += "\n"
    pretty_text = pretty_text[:-1]
    await service_status_matcher.finish(pretty_text)


def extract_str_list(command_arg: Message = CommandArg()):
    return command_arg.extract_plain_text().split()


service_add_matcher = on_command(
    "监控服务新增",
    aliases={"监控服务添加", "监控服务增加", "添加监控服务", "增加监控服务", "新增监控服务"},
    permission=SUPERUSER,
)


@service_add_matcher.handle()
async def _(command_arg_list: List[str] = Depends(extract_str_list)):
    if len(command_arg_list) < 3:
        await service_add_matcher.finish(f"参数不足\n监控服务新增 <协议> <名称> <地址>")
    protocol = command_arg_list[0]
    name = command_arg_list[1]
    host = command_arg_list[2]
    try:
        manager.bind_new_service(protocol, name, host)
    except ProtocolUnsopportError:
        await service_add_matcher.finish(
            f"暂不支持协议 \"{protocol}\" ！\n支持的协议： {'、'.join(support_protocol())}"
        )
    except NameConflictError:
        await service_add_matcher.finish("服务名称冲突！\n请修改新增服务名称或移除同名服务监控后再试")
    manager.save(CONFIG_FILE_PATH)
    await service_add_matcher.finish(f"{protocol} 协议绑定成功")


service_del_matcher = on_command("监控服务删除", aliases={"删除监控服务"}, permission=SUPERUSER)


@service_del_matcher.handle()
async def _(command_arg: Message = CommandArg()):
    try:
        manager.unbind_service_by_name(command_arg.extract_plain_text())
    except NameNotFoundError:
        await service_del_matcher.finish("操作失败：未找到该服务名称！")
    manager.save(CONFIG_FILE_PATH)
    await service_del_matcher.finish("已删除服务：" + command_arg)


service_group_matcher = on_command(
    "监控服务合并", aliases={"合并监控服务", "群组监控服务"}, permission=SUPERUSER
)


@service_group_matcher.handle()
async def _(command_arg_list: List[str] = Depends(extract_str_list)):
    if len(command_arg_list) < 3:
        await service_group_matcher.finish(f"参数不足\n合并监控服务 <名称1> <名称2> <群组名称>")
    bind_service_name_list = command_arg_list[:-1]
    name = command_arg_list[-1]
    try:
        manager.bind_group_by_name(bind_service_name_list, name)
    except NameNotFoundError:
        await service_group_matcher.finish("操作失败：合并的服务名称中有一个或多个无法找到！")
    manager.save(CONFIG_FILE_PATH)
    await service_group_matcher.finish(f"已成功合并 {len(bind_service_name_list)} 个服务")


service_set_matcher = on_command("监控服务修改", aliases={"修改监控服务"}, permission=SUPERUSER)


@service_set_matcher.handle()
async def _(command_arg_list: List[str] = Depends(extract_str_list)):
    if len(command_arg_list) < 3:
        await service_group_matcher.finish(f"参数不足\n修改监控服务 <名称> <参数> <值>")
    name = command_arg_list[0]
    command_arg_list = command_arg_list[1:]
    if len(command_arg_list) % 2 != 0:
        await service_set_matcher.finish("操作失败：修改的参数需成对以 <参数名> <值> 方法提供")
    settings_list: List[Tuple[str, str]] = []
    for i in range(0, len(command_arg_list) - 1, 2):
        settings_list.append((command_arg_list[i], command_arg_list[i + 1]))
    logger.debug(f"Modifying settings: {name} @ {settings_list}")
    manager.save(CONFIG_FILE_PATH)
    try:
        for key, value in settings_list:
            manager.modify_service_param(name, key, value)
    except NameNotFoundError:
        manager.load(CONFIG_FILE_PATH)
        await service_set_matcher.finish("操作失败：修改的服务名或参数名未找到")
    except ValidationError:
        manager.load(CONFIG_FILE_PATH)
        await service_set_matcher.finish("操作失败：参数格式或类型不正确")
    except:
        manager.load(CONFIG_FILE_PATH)
        await service_set_matcher.finish("操作失败：内部错误")
    manager.save(CONFIG_FILE_PATH)
    await service_set_matcher.finish(f"服务 {name} 参数修改成功")


reload_config_matcher = on_command("服务状态载入配置", permission=SUPERUSER)


@reload_config_matcher.handle()
async def _():
    manager.load(CONFIG_FILE_PATH)
    await reload_config_matcher.finish("已重新载入服务状态配置")



class ProtocolUnsopportError(Exception):
    def __init__(self, *args: object) -> None:
        super().__init__(*args)


class NameConflictError(Exception):
    def __init__(self, *args: object) -> None:
        super().__init__(*args)


class NameNotFoundError(Exception):
    def __init__(self, *args: object) -> None:
        super().__init__(*args)


class ParamInvalidError(Exception):
    def __init__(self, *args: object) -> None:
        super().__init__(*args)


class ParamCountInvalidError(Exception):
    def __init__(self, *args: object) -> None:
        super().__init__(*args)



from __future__ import annotations

from typing import Union, Dict, List
import random

"""
自定义协议DEMO

该demo将演示如何自定义一个可用概率为随机的协议（概率可调节）

更多说明请前往：https://github.com/OREOCODEDEV/nonebot-plugin-servicestate

该协议将有 2 个可调节参数
always_malfunction：是否总是返回故障状态
normal_rate: always_malfunction为False时，返回可用状态的机率

注意：该文件仅保证适用于当前版本的nonebot-plugin-servicestate
若后续插件版本更新，自定义协议需要的某些方法或字段可能会产生变更
"""

# 从内部继承抽象基类BaseProtocol以及协议参数类BaseProtocolData
from .protocol import BaseProtocol, BaseProtocolData
from nonebot.log import logger  # 导入 NoneBot2 日志模块


class DemoProtocolData(BaseProtocolData):  # 继承协议参数类BaseProtocolData
    """
    在这里声明你的自定义参数变量
    """

    always_malfunction: bool = False  # 该协议的自定义参数：是否总是返回故障状态
    normal_rate: int = 50  # 该协议的自定义参数：可用状态的机率


class DEMOProtocol(BaseProtocol):  # 类名可随意填写，但记得继承上面导入的BaseProtocol
    _PROTOCOL_NAME = "DemoProtocol"  # 协议名称，不得与正在使用的协议名称相同
    _DATA_MODEL = DemoProtocolData  # 声明该协议的参数类

    async def detect(self) -> bool:  # 实现探测方法，返回bool，注意该方法名不可更改
        """
        在此处实现你的自定义协议的处理代码
        最终返回bool（True为可用，False为故障）
        """
        if self.data.always_malfunction:
            # 自定义参数中always_malfunction参数为True，永远返回不可用状态
            logger.info("Custom protocol refused")  # 在控制台记录一些信息
            return False  # 永远返回不可用状态
        random_result: bool = (
            random.random() < self.data.normal_rate / 100
        )  # 按概率随机生成可用状态
        logger.info(f"Custom protocol random state: {random_result}")  # 在控制台记录一些信息
        return random_result  # 返回随机生成的可用状态（bool型）



from __future__ import annotations

from typing import Union, Dict, List, Any
from asyncio import gather

from .protocol import BaseProtocol, support_protocol
from .exception import NameNotFoundError, ProtocolUnsopportError


class ServiceStatus:
    def __init__(self) -> None:
        self.bind_services: List[BaseProtocol] = []

    def __contains__(self, item):
        if isinstance(item, str):
            for i in self.bind_services:
                if i == item:
                    return True
        if isinstance(item, BaseProtocol):
            return item in self.bind_services
        return False

    def get_service_instance_by_name(self, name: str) -> BaseProtocol:
        for i in self.bind_services:
            if name == i:
                return i
        raise NameNotFoundError

    def bind_service(self, service: BaseProtocol):
        self.bind_services.append(service)

    def unbind_service(self, unbind_service: BaseProtocol):
        if unbind_service not in self:
            raise NameNotFoundError
        self.bind_services.pop(self.bind_services.index(unbind_service))

    def unbind_service_by_name(self, unbind_service_name: str):
        service_instance = self.get_service_instance_by_name(unbind_service_name)
        if service_instance is not None:
            self.unbind_service(service_instance)

    async def get_detect_result(self) -> Dict[str, bool]:
        tasks = [service.detect() for service in self.bind_services]
        result = await gather(*tasks)
        ret_dict = {}
        for i, j in zip(self.bind_services, result):
            ret_dict[i.data.name] = j
        return ret_dict

    @classmethod
    def load(cls, source: Dict[str, List]) -> ServiceStatus:
        instance = cls()
        for key, value in source.items():
            if key not in support_protocol():
                raise ProtocolUnsopportError(f"Unsopported protocol: {key} !")
            for this_service_config in value:
                this_service_instance = BaseProtocol._support_protocol[key].load(
                    this_service_config
                )
                instance.bind_services.append(this_service_instance)
        return instance

    def export(self) -> Dict[str, List[Dict]]:
        ret_dict = {}
        for i in support_protocol():
            ret_dict[i] = []
            for j in self.bind_services:
                if j._PROTOCOL_NAME != i:
                    continue
                ret_dict[i].append(j.export())
        return ret_dict


class ServiceStatusGroup:
    def __init__(self) -> None:
        self.bind_services_group: Dict[str, ServiceStatus] = {}

    def __contains__(self, item):
        if isinstance(item, str):
            return item in self.bind_services_group.keys()
        if isinstance(item, ServiceStatus):
            return item in self.bind_services_group.values()
        return False

    def bind_group(
        self,
        services: List[BaseProtocol],
        name: str,
    ):
        self.bind_services_group[name] = ServiceStatus()
        for this_service in services:
            self.bind_services_group[name].bind_service(this_service)
            # service_status_instance.unbind_service(this_service) # 由NonebotPluginServiceStateManager实现

    def unbind_group_by_name(self, unbind_service_group_name: str):
        if unbind_service_group_name not in self.bind_services_group:
            raise NameNotFoundError
        del self.bind_services_group[unbind_service_group_name]

    async def get_detect_result(self) -> Dict[str, bool]:
        ret_result = {}
        for name, this_service_group in self.bind_services_group.items():
            ret_result[name] = True
            for i in (await this_service_group.get_detect_result()).values():
                if not i:
                    ret_result[name] = False
                    break
        return ret_result

    @classmethod
    def load(cls, source: Dict[str, Dict[str, List]]) -> ServiceStatusGroup:
        instance = cls()
        for name, service_status_config in source.items():
            instance.bind_services_group[name] = ServiceStatus.load(
                service_status_config
            )
        return instance

    def export(self) -> Dict[str, Dict[str, List]]:
        ret_dict = {}
        for name, service_status_instance in self.bind_services_group.items():
            ret_dict[name] = service_status_instance.export()
        return ret_dict



from __future__ import annotations
from abc import ABC, abstractmethod, abstractclassmethod
from typing import Union, Dict, List, Type
from pydantic import BaseModel


class BaseProtocolData(BaseModel):
    name: str = "Unknown"
    host: str = "127.0.0.1"
    timeout: int = 3


class BaseProtocol(ABC):
    _support_protocol: dict = {}
    _PROTOCOL_NAME = None
    _DATA_MODEL = BaseProtocolData

    def __init__(self, *args, **kw) -> None:
        self.data = self._DATA_MODEL(*args, **kw)

    def __init_subclass__(cls) -> None:
        for this_subclass in BaseProtocol.__subclasses__():
            if this_subclass._PROTOCOL_NAME is None:
                raise NotImplementedError('Protocol should have "_PROTOCOL_NAME"')
            if this_subclass._PROTOCOL_NAME in BaseProtocol._support_protocol:
                continue
            BaseProtocol._support_protocol[this_subclass._PROTOCOL_NAME] = this_subclass
        return super().__init_subclass__()

    def __eq__(self, __o: Union[str, BaseProtocol]) -> bool:
        if isinstance(__o, str):
            return True if __o == self.data.name else False
        if not isinstance(__o, BaseProtocol):
            return False
        if self.data.name != __o.data.name:
            return False
        if self.data.host != __o.data.host:
            return False
        if self._PROTOCOL_NAME != __o._PROTOCOL_NAME:
            return False
        return True

    @abstractmethod
    async def detect(self) -> bool:
        return False

    def export(self) -> Dict:
        return self.data.dict()

    @classmethod
    def load(cls, source: Dict[str, Union[str, int, None]]):
        return cls(**source)


def support_protocol() -> List[str]:
    return list(BaseProtocol._support_protocol.keys())



from __future__ import annotations

from httpx import AsyncClient
from typing import Union, Dict, List, Any

from .protocol import BaseProtocol, BaseProtocolData

from nonebot.log import logger


class HTTPProtocolData(BaseProtocolData):
    proxies: Union[str, None] = None


class HTTPProtocol(BaseProtocol):
    _PROTOCOL_NAME = "HTTP"
    _DATA_MODEL = HTTPProtocolData

    async def detect(self) -> bool:
        async with AsyncClient(
            proxies=self.data.proxies,
            verify=False,
            follow_redirects=True,
            timeout=self.data.timeout,
        ) as client:
            try:
                respond = await client.get(url=self.data.host)
            except:
                logger.debug(f"GET -> {self.data.host} FAIL")
                return False
            if not respond:
                logger.debug(f"GET -> {self.data.host} FAIL")
                return False
            if respond.status_code != 200:
                logger.debug(f"GET -> {self.data.host} FAIL")
                return False
            logger.debug(f"GET -> {self.data.host} OK")
            return True



from __future__ import annotations

from typing import Union, Dict, List

from .protocol import BaseProtocol, BaseProtocolData

from nonebot.log import logger
import asyncio


class TCPPRotocolData(BaseProtocolData):
    port: int = 80


class TCP_Protocol(BaseProtocol):
    _PROTOCOL_NAME = "TCP"
    _DATA_MODEL = TCPPRotocolData

    async def detect(self) -> bool:
        try:
            await asyncio.open_connection(self.data.host, self.data.port)
            logger.debug(f"TCP -> {self.data.host}:{self.data.port} OK")
            return True
        except:
            logger.debug(f"TCP -> {self.data.host}:{self.data.port} FAIL")
            return False



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nonebot_plugin_servicestate', 'nonebot_plugin_servicestate.protocol']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.20.0,<0.21.0',
 'nonebot-adapter-onebot>=2.1.0,<3.0.0',
 'nonebot2>=2.0.0b2,<3.0.0',
 'pydantic>=1.10.2,<2.0.0']

setup_kwargs = {
    'name': 'nonebot-plugin-servicestate',
    'version': '0.0.4',
    'description': '基于NoneBot2的状态监测插件',
    'long_description': '<p align="center">\n  <a href="https://v2.nonebot.dev/"><img src="https://v2.nonebot.dev/logo.png" width="200" height="200" alt="nonebot"></a>\n</p>\n\n<div align="center">\n\n# NoneBot Plugin ServiceState\n\n_✨ NoneBot 服务状态查询插件 ✨_\n\n</div>\n\n<p align="center">\n  <a href="https://raw.githubusercontent.com/nonebot/plugin-apscheduler/master/LICENSE">\n    <img src="https://img.shields.io/github/license/nonebot/plugin-apscheduler.svg" alt="license">\n  </a>\n  <a href="https://pypi.python.org/pypi/nonebot-plugin-apscheduler">\n    <img src="https://img.shields.io/pypi/v/nonebot-plugin-apscheduler.svg" alt="pypi">\n  </a>\n  <img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">\n</p>\n\n## 简介\n\n可通过 `服务状态` 查询当前服务器各功能 API 可用状态\n\n例如：\n\n```\nO 可用 | 会战面板\nO 可用 | SSH登录\nX 故障 | 涩图\nO 可用 | 画图\nX 故障 | ChatGPT\n```\n\n\n## 特色\n\n- 易于上手：所有配置项的增删查改都可通过文本交互实现，无需修改任何配置文件\n- 异步支持：所有协议均通过异步实现，无需担心探测过程中造成堵塞\n- 易于拓展：开发者只需实现部分核心方法即可增添新协议支持，详情参考[添加协议](#添加协议)\n\n\n## 安装\n\n使用 `nb-cli` 安装（推荐）：\n```\nnb plugin install nonebot-plugin-servicestate\n```\n\n使用 `pip` 安装：\n```\npip install nonebot-plugin-servicestate\n```\n\n使用 `git clone` 安装：\n```\ngit clone https://github.com/OREOCODEDEV/nonebot-plugin-servicestate.git\n```\n\n\n## 使用\n\n### 服务状态查询\n可通过发送 `服务状态` 获取当前绑定的监控服务可用状态\n\n**只有服务状态查询无权限要求，监控服务的增删查改均需要 NoneBot 管理员权限，若监控服务增删查改命令不响应，请检查 NoneBot 是否已正确配置管理员**\n\n### 新增监控服务\n可通过发送 `添加监控服务 <协议> <名称> <地址>` 以新增需要监控的服务\n* 可在[此处](#协议支持)查看所有受支持的协议\n```\n添加监控服务 HTTP git截图 https://github.com\n```\n\n### 修改监控服务\n可通过发送 `修改监控服务 <名称> <参数名> <参数内容>` 以修改监控服务的参数\n* 不同协议支持修改的参数字段不同，具体请参考[协议支持](#协议支持)\n```\n修改监控服务 git截图 proxies http://127.0.0.1:10809\n```\n\n### 群组监控服务\n**当前版本服务群组后暂未支持修改及解散群组，只能删除群组，请注意** ~~除非改配置文件~~\n\n当多个API共同支持某项服务时，可通过 `群组监控服务 <名称1> <名称2> <群组名称>` 群组多个服务为一个显示\n\n* 只有当群组中的所有服务都为可用状态时，群组才显示为可用，当有一个或多个服务为故障状态时，群组都显示为故障\n\n例：假设当前已设置好 涩图信息API 和 涩图图床 两个监控服务，可通过下列命令组合为一个服务\n```\n群组监控服务 涩图信息API 涩图图床 涩图\n```\n群组命令前：\n```\nO 可用 | 涩图信息API\nX 故障 | 涩图图床\n```\n群组命令后：\n```\nX 故障 | 涩图\n```\n\n### 删除监控服务\n可通过发送 `删除监控服务 <名称>` 以不再监测该服务\n```\n删除监控服务 git截图\n```\n\n\n## 协议支持\n\n以下是项目当前支持的协议，以及可被通过修改命令配置的字段\n\n### HTTP GET\n- 协议名称：`HTTP`\n- [x] 状态查询：探测地址超时前返回状态 200 为可用\n- [x] 服务名称：`name` @ [str]\n- [x] 监测地址：`host` @ [str]\n- [x] 超时时间：`timeout` @ [int]\n- [x] 代理地址：`proxies` @ [str, None]\n- [ ] 请求头：暂未支持\n- [ ] UA：暂未支持\n- [ ] Cookie：暂未支持\n- [ ] 有效响应码：暂未支持\n- [ ] 内容正则判定：暂未支持\n\n### TCP\n- 协议名称：`TCP`\n- [x] 状态查询：探测地址超时前成功建立连接为可用\n- [x] 服务名称：`name` @ [str]\n- [x] 监测地址：`host` @ [str]\n- [x] 端口：`port` @ [int]\n- [ ] 代理地址：暂未支持\n- [ ] 超时时间：暂未支持\n\n### PING\n- [ ] 状态查询：暂未支持\n- [ ] 监测地址：暂未支持\n- [ ] 代理地址：暂未支持\n- [ ] 超时时间：暂未支持\n\n\n## 添加协议\n\n### 说明\n**本段内容面向开发者，如不理解可跳过本段** \n\n若某项服务可用需要特殊的可用性检查逻辑，且无法通过通用协议支持实现（如动态解析内容并获取链接跳转）或当前协议暂未支持该判定特性时，可通过添加新的协议快速实现\n\n### 编写\n项目`.\\protocol`中内置了一个demo协议\n[demo.py](https://github.com/OREOCODEDEV/nonebot-plugin-servicestate/blob/main/nonebot_plugin_servicestate/protocol/demo.py)\n实现了一个可用概率为随机的协议，你可以参照内部的注释，编写自己的自定义协议方法\n\n下列步骤中默认均按照demo协议编写，如需要自定义协议请按照实际情况操作\n\n### 注册\n在`.\\protocol\\__init__.py`中导入需要注册的demo协议\n```\nfrom .demo import DEMO_Protocol\n```\n\n### 使用\n现在，你已经完成自定义协议的所有步骤，可直接使用你的自定义协议了\n\n添加demo协议命令：`添加监控服务 DemoProtocol DemoName your_url`\n\n修改随机可用概率为 25% ：`修改监控服务 DemoName normal_rate 25`\n\n修改为永远故障状态：`修改监控服务 DemoName always_malfunction True`\n\n使用上述命令并通过`服务状态`命令观察它们的变化吧！\n\n\n\n## Todo\n- [ ] 支持更多配置字段\n- [ ] 协议配置项合法检查接口支持\n- [ ] 协议载入配置方法统一实现\n- [ ] 协议必填配置项接口支持\n- [ ] 鲁棒性增强\n- [ ] 群组~~增删~~查改支持\n- [ ] OneBotV11配置文件收发\n- [ ] 不同用户监控服务绑定支持（咕咕咕\n- [ ] 还有上面一大堆协议中暂未支持的内容\n',
    'author': 'OREOCODEDEV',
    'author_email': '17620745509@126.COM',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/OREOCODEDEV/nonebot-plugin-servicestate',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
